==> bettertrims-4.0.0%2B1.21.1-fabric-sources.jar: com/bawnorton/bettertrims/data/provider/BetterTrimsEntityTypeTagProvider.java <==
package com.bawnorton.bettertrims.data.provider;

//? if fabric {
import com.bawnorton.bettertrims.data.BetterTrimsEntityTypeTags;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1299;
import net.minecraft.class_3483;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;

public class BetterTrimsEntityTypeTagProvider extends FabricTagProvider.EntityTypeTagProvider {
	public BetterTrimsEntityTypeTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
		super(output, registriesFuture);
	}

	@Override
	protected void method_10514(class_7225.class_7874 wrapperLookup) {
		valueLookupBuilder(BetterTrimsEntityTypeTags.CONDUCTIVE_PROJECTILES)
				.forceAddTag(class_3483.field_21508)
				.add(class_1299.field_6127);
	}

	//? if 1.21.1 {
	private FabricTagBuilder valueLookupBuilder(class_6862<class_1299<?>> type) {
		return getOrCreateTagBuilder(type);
	}
	//?}
}
//?} else {

/*import com.bawnorton.bettertrims.BetterTrims;
import com.bawnorton.bettertrims.data.BetterTrimsEntityTypeTags;
import net.minecraft.core.HolderLookup;
import net.minecraft.core.registries.Registries;
import net.minecraft.data.PackOutput;
import net.minecraft.data.tags.TagsProvider;
import net.minecraft.resources.ResourceKey;
import net.minecraft.tags.EntityTypeTags;
import net.minecraft.tags.TagKey;
import net.minecraft.world.entity.EntityType;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.concurrent.CompletableFuture;

//? if >=1.21.8 {
import net.minecraft.data.tags.TagAppender;
//?} else {
/^import net.neoforged.neoforge.common.data.ExistingFileHelper;
import org.jetbrains.annotations.Nullable;
^///?}

public class BetterTrimsEntityTypeTagProvider extends TagsProvider<EntityType<?>> {
	//? if <1.21.8 {
	/^public BetterTrimsEntityTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider, @Nullable ExistingFileHelper existingFileHelper) {
			super(output, Registries.ENTITY_TYPE, lookupProvider, BetterTrims.MOD_ID, existingFileHelper);
	}
	^///?} else {
	public BetterTrimsEntityTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider) {
		super(output, Registries.ENTITY_TYPE, lookupProvider, BetterTrims.MOD_ID);
	}
	//?}

	@Override
	protected void addTags(@NotNull HolderLookup.Provider provider) {
		tag(BetterTrimsEntityTypeTags.CONDUCTIVE_PROJECTILES)
				.addTag(EntityTypeTags.ARROWS)
				.add(EntityType.TRIDENT.builtInRegistryHolder().key());
	}

	//? if >=1.21.8 {
	private TagAppender<ResourceKey<EntityType<?>>, EntityType<?>> tag(TagKey<EntityType<?>> type) {
		return TagAppender.forBuilder(getOrCreateRawBuilder(type));
	}
	//?}
}

*///?}

==> bettertrims-4.0.2%2B1.21.10-fabric-sources.jar: com/bawnorton/bettertrims/data/provider/BetterTrimsEntityTypeTagProvider.java <==
package com.bawnorton.bettertrims.data.provider;

//? if fabric {
import com.bawnorton.bettertrims.data.BetterTrimsEntityTypeTags;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1299;
import net.minecraft.class_3483;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;

public class BetterTrimsEntityTypeTagProvider extends FabricTagProvider.EntityTypeTagProvider {
	public BetterTrimsEntityTypeTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
		super(output, registriesFuture);
	}

	@Override
	protected void method_10514(class_7225.class_7874 wrapperLookup) {
		valueLookupBuilder(BetterTrimsEntityTypeTags.CONDUCTIVE_PROJECTILES)
				.forceAddTag(class_3483.field_21508)
				.method_71554(class_1299.field_6127);
	}

	//? if 1.21.1 {
	/*private FabricTagBuilder valueLookupBuilder(TagKey<EntityType<?>> type) {
		return getOrCreateTagBuilder(type);
	}
	*///?}
}
//?} else {

/*import com.bawnorton.bettertrims.BetterTrims;
import com.bawnorton.bettertrims.data.BetterTrimsEntityTypeTags;
import net.minecraft.core.HolderLookup;
import net.minecraft.core.registries.Registries;
import net.minecraft.data.PackOutput;
import net.minecraft.data.tags.TagsProvider;
import net.minecraft.resources.ResourceKey;
import net.minecraft.tags.EntityTypeTags;
import net.minecraft.tags.TagKey;
import net.minecraft.world.entity.EntityType;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.concurrent.CompletableFuture;

//? if >=1.21.8 {
import net.minecraft.data.tags.TagAppender;
//?} else {
/^import net.neoforged.neoforge.common.data.ExistingFileHelper;
import org.jetbrains.annotations.Nullable;
^///?}

public class BetterTrimsEntityTypeTagProvider extends TagsProvider<EntityType<?>> {
	//? if <1.21.8 {
	/^public BetterTrimsEntityTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider, @Nullable ExistingFileHelper existingFileHelper) {
			super(output, Registries.ENTITY_TYPE, lookupProvider, BetterTrims.MOD_ID, existingFileHelper);
	}
	^///?} else {
	public BetterTrimsEntityTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider) {
		super(output, Registries.ENTITY_TYPE, lookupProvider, BetterTrims.MOD_ID);
	}
	//?}

	@Override
	protected void addTags(@NotNull HolderLookup.Provider provider) {
		tag(BetterTrimsEntityTypeTags.CONDUCTIVE_PROJECTILES)
				.addTag(EntityTypeTags.ARROWS)
				.add(EntityType.TRIDENT.builtInRegistryHolder().key());
	}

	//? if >=1.21.8 {
	private TagAppender<ResourceKey<EntityType<?>>, EntityType<?>> tag(TagKey<EntityType<?>> type) {
		return TagAppender.forBuilder(getOrCreateRawBuilder(type));
	}
	//?}
}

*///?}
